pub struct RefMut<T: ?Sized> { /* private fields */ }Expand description
A sendable exclusive reference backed by a Lien.
A RefMut<T> represents an exclusive borrow of T from a Scope. Like
a static borrow with &mut T, this forces the Scope to outlive any
RefMuts made from it. But like an Arc, RefMut<T> carries no lifetime
(it’s atomically reference-counted at runtime) and is thread-safe.
RefMut<T> requires T: Send to be Send, like &mut T:
use std::rc::Rc;
fn assert_send<T: Send>(_: T) {}
let mut v = Rc::new(42);
let scope = scope!();
let r = scope.lend_mut(&mut v);
assert_send(r); // 💥 Rc is not SendCan’t clone a RefMut:
fn needs_clone<T: Clone>(_: &T) {}
let mut v = 42;
let scope = scope!();
let r = scope.lend_mut(&mut v);
needs_clone(&r); // 💥 RefMut is not CloneCan’t have two RefMuts to the same value:
let mut v = 42;
let scope = scope!();
let r1 = scope.lend_mut(&mut v);
let r2 = scope.lend_mut(&mut v); // 💥 already borrowed mutably
drop(r1);Implementations
Sourceimpl<T: ?Sized> RefMut<T>
impl<T: ?Sized> RefMut<T>
Sourcepub fn map<R>(
self,
f: impl for<'a> FnOnce(&'a mut T, Rehypothecator<'a>) -> R,
) -> R
pub fn map<R>( self, f: impl for<'a> FnOnce(&'a mut T, Rehypothecator<'a>) -> R, ) -> R
Consumes this RefMut and re-lends its contents (or sub-fields) against
the original scope’s rc.
Sourcepub fn as_ptr(this: &Self) -> *const T
pub fn as_ptr(this: &Self) -> *const T
Returns a raw pointer to the RefMut’s referent.
The caller must ensure that the RefMut outlives the pointer this
function returns, or else it may end up dangling.
Sourcepub fn as_mut_ptr(this: &mut Self) -> *mut T
pub fn as_mut_ptr(this: &mut Self) -> *mut T
Returns a raw mutable pointer to the RefMut’s referent.
The caller must ensure that the RefMut outlives the pointer this
function returns, or else it may end up dangling.